"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const ts_node_1 = require("ts-node");
// Use the project's version of TypeScript if available,
// otherwise fall back to using the copy that `@now/node` uses.
let compiler;
try {
    compiler = require.resolve('typescript', {
        paths: [process.cwd(), __dirname],
    });
}
catch (e) {
    compiler = 'typescript';
}
ts_node_1.register({
    compiler,
    compilerOptions: {
        allowJs: true,
        esModuleInterop: true,
        jsx: 'react',
    },
    transpileOnly: true,
});
const http_1 = __importDefault(require("http"));
const path_1 = __importDefault(require("path"));
const helpers_1 = require("./helpers");
function listen(server, port, host) {
    return new Promise(resolve => {
        server.listen(port, host, () => {
            resolve();
        });
    });
}
async function main() {
    const entrypoint = process.env.NOW_DEV_ENTRYPOINT;
    delete process.env.NOW_DEV_ENTRYPOINT;
    if (!entrypoint) {
        throw new Error('`NOW_DEV_ENTRYPOINT` must be defined');
    }
    const config = JSON.parse(process.env.NOW_DEV_CONFIG || '{}');
    delete process.env.NOW_DEV_CONFIG;
    const shouldAddHelpers = !(config.helpers === false || process.env.NODEJS_HELPERS === '0');
    const entrypointPath = path_1.default.join(process.cwd(), entrypoint);
    const handler = await Promise.resolve().then(() => __importStar(require(entrypointPath)));
    const server = shouldAddHelpers
        ? helpers_1.createServerWithHelpers(handler.default)
        : http_1.default.createServer(handler.default);
    await listen(server, 0, '127.0.0.1');
    const address = server.address();
    if (typeof process.send === 'function') {
        process.send(address);
    }
    else {
        console.log('Dev server listening:', address);
    }
}
main().catch(err => {
    console.error(err);
    process.exit(1);
});
